@@ -67,6 +67,29 @@ def test_request_token_auth_in_ctor():
     assert responses.calls[0].request.url == iam_url
     assert responses.calls[0].request.headers['Authorization'] != default_auth_header
     assert responses.calls[0].response.text == response
+    assert 'scope' not in responses.calls[0].response.request.body
+
+@responses.activate
+def test_request_token_auth_in_ctor_with_scope():
+    iam_url = "https://iam.cloud.ibm.com/identity/token"
+    response = """{
+        "access_token": "oAeisG8yqPY7sFR_x66Z15",
+        "token_type": "Bearer",
+        "expires_in": 3600,
+        "expiration": 1524167011,
+        "refresh_token": "jy4gl91BQ"
+    }"""
+    default_auth_header = 'Basic Yng6Yng='
+    responses.add(responses.POST, url=iam_url, body=response, status=200)
+
+    token_manager = IAMTokenManager("apikey", url=iam_url, client_id='foo', client_secret='bar', scope='john snow')
+    token_manager.request_token()
+
+    assert len(responses.calls) == 1
+    assert responses.calls[0].request.url == iam_url
+    assert responses.calls[0].request.headers['Authorization'] != default_auth_header
+    assert responses.calls[0].response.text == response
+    assert 'scope=john+snow' in responses.calls[0].response.request.body
 
 @responses.activate
 def test_request_token_unsuccessful():
@@ -119,6 +142,7 @@ def test_request_token_auth_in_ctor_client_id_only():
     assert responses.calls[0].request.url == iam_url
     assert responses.calls[0].request.headers.get('Authorization') is None
     assert responses.calls[0].response.text == response
+    assert 'scope' not in responses.calls[0].response.request.body
 
 @responses.activate
 def test_request_token_auth_in_ctor_secret_only():
@@ -139,6 +163,7 @@ def test_request_token_auth_in_ctor_secret_only():
     assert responses.calls[0].request.url == iam_url
     assert responses.calls[0].request.headers.get('Authorization') is None
     assert responses.calls[0].response.text == response
+    assert 'scope' not in responses.calls[0].response.request.body
 
 @responses.activate
 def test_request_token_auth_in_setter():
@@ -161,6 +186,7 @@ def test_request_token_auth_in_setter():
     assert responses.calls[0].request.url == iam_url
     assert responses.calls[0].request.headers['Authorization'] != default_auth_header
     assert responses.calls[0].response.text == response
+    assert 'scope' not in responses.calls[0].response.request.body
 
 @responses.activate
 def test_request_token_auth_in_setter_client_id_only():
@@ -182,6 +208,7 @@ def test_request_token_auth_in_setter_client_id_only():
     assert responses.calls[0].request.url == iam_url
     assert responses.calls[0].request.headers.get('Authorization') is None
     assert responses.calls[0].response.text == response
+    assert 'scope' not in responses.calls[0].response.request.body
 
 @responses.activate
 def test_request_token_auth_in_setter_secret_only():
@@ -204,3 +231,28 @@ def test_request_token_auth_in_setter_secret_only():
     assert responses.calls[0].request.url == iam_url
     assert responses.calls[0].request.headers.get('Authorization') is None
     assert responses.calls[0].response.text == response
+    assert 'scope' not in responses.calls[0].response.request.body
+
+@responses.activate
+def test_request_token_auth_in_setter_scope():
+    iam_url = "https://iam.cloud.ibm.com/identity/token"
+    response = """{
+        "access_token": "oAeisG8yqPY7sFR_x66Z15",
+        "token_type": "Bearer",
+        "expires_in": 3600,
+        "expiration": 1524167011,
+        "refresh_token": "jy4gl91BQ"
+    }"""
+    responses.add(responses.POST, url=iam_url, body=response, status=200)
+
+    token_manager = IAMTokenManager("iam_apikey")
+    token_manager.set_client_id_and_secret(None, 'bar')
+    token_manager.set_headers({'user':'header'})
+    token_manager.set_scope('john snow')
+    token_manager.request_token()
+
+    assert len(responses.calls) == 1
+    assert responses.calls[0].request.url == iam_url
+    assert responses.calls[0].request.headers.get('Authorization') is None
+    assert responses.calls[0].response.text == response
+    assert 'scope=john+snow' in responses.calls[0].response.request.body
